<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Geral\Services\{MarcacaoService, OcorrenciaService};

class MarcacaoController extends Crud {

    /** @var MarcacaoService */
    protected $marcacaoService;

    public function __construct(EntityManager $entityManager, MarcacaoService $marcacaoService, OcorrenciaService $ocorrenciaService) {
      $this->entityManager      = $entityManager;
      $this->marcacaoService    = $marcacaoService;
      $this->ocorrenciaService  = $ocorrenciaService;
    }

    public function setMarcacao(
        $nrvinculom,
        $nrorg,
        $cdoperador,
        $dslatitude,
        $dslongitude,
        $marcacaoAlmoco = false,
        $photoContent = null
    ) {
        try {
            $nrmarcacaoponto = $this->marcacaoService->setMarcacao(
                $nrvinculom,
                $nrorg,
                $cdoperador,
                $dslatitude,
                $dslongitude,
                $photoContent
            );

            if ($marcacaoAlmoco) {
                $this->ocorrenciaService->setOcorrenciaAlmoco($nrvinculom, $nrorg, $nrmarcacaoponto, $cdoperador);
            }
            
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function registraMarcacaoIntervalo(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $row = current($rows);
    
            $success = $this->setMarcacao(
                $row['NRVINCULOM'],
                $row['NRORG'],
                $row['CDOPERADOR'],
                $row['DSLATITUDE'],
                $row['DSLONGITUDE'],
                false,
                $row['DSPATH']
            );
            $response->addDataSet(new DataSet('setMarcacaoIntervalo', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function registraMarcacaoAlmoco(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $row = current($rows);
    
            $success = $this->setMarcacao(
                $row['NRVINCULOM'],
                $row['NRORG'],
                $row['CDOPERADOR'],
                $row['DSLATITUDE'],
                $row['DSLONGITUDE'],
                true,
                $row['DSPATH']
            );
            $response->addDataSet(new DataSet('setMarcacaoAlmoco', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function registraOcorrenciaPonto(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            $nrmarcacaoponto = $this->marcacaoService->setMarcacao(
                $row['NRVINCULOM'],
                $row['NRORG'],
                $row['CDOPERADOR'],
                $row['DSLATITUDE'],
                $row['DSLONGITUDE'],
                $row['DSPATH']
            );

            $row['NRMARCACAOPONTO'] = $nrmarcacaoponto;
            
            $success = $this->ocorrenciaService->setOcorrenciaFreq($row);
            
            $response->addDataSet(new DataSet('setOcorrenciaPonto', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function validaMarcacaoDistancia(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $row = current($rows);
    
            $validacoes = $this->marcacaoService->getValidacaoMarcacaoDistancia(
                $row['NRVINCULOM'],
                $row['NRORG'],
                $row['DSLATITUDE'],
                $row['DSLONGITUDE']
            );
            $response->addDataSet(new DataSet('validacoesMarcacao', array('validacoesMarcacao' => $validacoes)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getParesMarcacoesDia(
        DTO\Request\Filter  $request,
        DTO\Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];
            $dia       = $row['DIA'];

            $dataSet = $this->marcacaoService->
                getParesMarcacoesDia($nrOrg, $nrVinculo, $dia);

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function saveParesMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow();

            $nrOrg             = (int)      $row['NRORG'];
            $nrVinculo         = (int)      $row['NRVINCULOM'];
            $dia               = (array)    $row['DIA'];
            $hrEntrada         = (string)   $row['HRENTRADA'];
            $hrSaida           = (string)   $row['HRSAIDA'];

            $nrMarcacoes = $this->marcacaoService->saveParesMarcacao(
                $nrOrg,
                $nrVinculo,
                $dia,
                $hrEntrada,
                $hrSaida
            );

            $dataSet = [
                'nrMarcacoes' => $nrMarcacoes
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeParesMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow();

            $nrOrg             = (int)      $row['NRORG'];
            $nrVinculo         = (int)      $row['NRVINCULOM'];
            $dia               = (array)    $row['DIA'];
            $hrEntrada         = (string)   $row['HRENTRADA'];
            $hrSaida           = (string)   $row['HRSAIDA'];

            $nrMarcacoes = $this->marcacaoService->removeParesMarcacao(
                $nrOrg,
                $nrVinculo,
                $dia,
                $hrEntrada,
                $hrSaida
            );

            $dataSet = [
                'nrMarcacoes' => $nrMarcacoes
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow();

            $nrOrg              = (int)      $row['NRORG'];
            $nrVinculo          = (int)      $row['NRVINCULOM'];
            $nrMarcacaoponto    = (string)   $row['NRMARCACAOPONTO'];

            $nrMarcacoes = $this->marcacaoService->removeMarcacao(
                $nrOrg,
                $nrVinculo,
                $nrMarcacaoponto
            );

            $dataSet = [
                'nrMarcacoes' => $nrMarcacoes
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function editParesMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow();

            $nrOrg          = (int)     $row['NRORG'];
            $nrVinculo      = (int)     $row['NRVINCULOM'];
            $hrentrada      = (string)  $row['HRENTRADA'];
            $hrsaida        = (string)  $row['HRSAIDA'];
            $dates          = (array)   $row['DATE'];
            $novahrentrada  = (string)  $row['NOVAHRENTRADA'];
            $novahrsaida    = (string)  $row['NOVAHRSAIDA'];

            $nrMarcacoes = $this->marcacaoService->editParesMarcacao(
                $nrOrg,
                $nrVinculo,
                $hrentrada,
                $hrsaida,
                $dates,
                $novahrentrada,
                $novahrsaida
            );

            $dataSet = [
                'nrMarcacoes' => $nrMarcacoes
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
    
    public function getServerTime(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $serverDateTime = $this->marcacaoService->getServerTime();

            $response->addDataSet(new DataSet('data', $serverDateTime));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function fixaEntradaSaida(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = $request->getRow();

            $nrOrg             = (int)    $row['NRORG'];
            $nrVinculo         = (int)    $row['NRVINCULOM'];
            $date              = (string) $row['DATE'];
            $nrMarcacaoEntrada = (int)    $row['NRMARCACAOENTRADA'];
            $nrMarcacaoSaida   = (int)    $row['NRMARCACAOSAIDA'];

            $status = $this->marcacaoService->fixaEntradaSaida(
                $nrOrg, $nrVinculo, $date,
                $nrMarcacaoEntrada, $nrMarcacaoSaida
            );

            if ($status['success']) {
                $dataset = [
                    'success' => true
                ];

                $response->addDataSet(new DataSet('data', $dataset));
            } else {
                $message = $status['message'];

                $response->addMessage(new Message($message));
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMarcacoesPontoDiaOpcoesFixarMarcacao(
        Request\Filter $request,
        Response       $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg             = (int)    $row['NRORG'];
            $nrVinculo         = (int)    $row['NRVINCULOM'];
            $date              = (string) $row['DATE'];

            $marcacoes = $this->marcacaoService->getMarcacoesPontoDiaOpcoesFixarMarcacao(
                $nrOrg, $nrVinculo, $date
            );

            $response->addDataSet(new DataSet('data', $marcacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function reverterEntradaSaida(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = $request->getRow();

            $nrOrg             = (int)    $row['NRORG'];
            $nrVinculo         = (int)    $row['NRVINCULOM'];
            $date              = (string) $row['DATE'];

            $success = $this->marcacaoService->reverterEntradaSaida(
                $nrOrg, $nrVinculo, $date
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}