<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

use EMS\PortalFuncionario\Geral\Services\MinhaHistoriaService;

class MinhaHistoriaController {
    public function __construct(MinhaHistoriaService $minhaHistoriaService) {
        $this->minhaHistoriaService = $minhaHistoriaService;
    }
    
    public function getDadosPessoais(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];

            $dadosPessoais = $this->minhaHistoriaService->getDadosPessoais($nrorg, $nrvinculom);
            
            $response->addDataSet(new DataSet('data', $dadosPessoais));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getComunicacaoParc(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];

            $comunicacao = $this->minhaHistoriaService->getComunicacaoParc($nrorg, $nrvinculom);
            
            $response->addDataSet(new DataSet('data', $comunicacao));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getEnderecoParc(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];

            $comunicacao = $this->minhaHistoriaService->getEnderecoParc($nrorg, $nrvinculom);
            
            $response->addDataSet(new DataSet('data', $comunicacao));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getContaCorrenteParc(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $nrvinculom = $params['NRVINCULOM'];

            $comunicacao = $this->minhaHistoriaService->getContaCorrenteParc($nrorg, $nrvinculom);
            
            $response->addDataSet(new DataSet('data', $comunicacao));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getAdressCEP(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $params = $request->getRow();

            $nrorg = $params['NRORG'];
            $cep = $params['CEP'];

            $adress = $this->minhaHistoriaService->getAdressCEP($nrorg, $cep);
            
            $response->addDataSet(new DataSet('data', $adress));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function solicitaAlteracao(DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            $success = $this->minhaHistoriaService->solicitaAlteracao($row);
            $response->addDataSet(new DataSet('solicitaAlteracao', array('success' => $success)));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getEstadocivil(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getEstadocivil(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getCondicaoFisica(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getCondicaoFisica(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getRacaPessoa(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getRacaPessoa(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getGrauinstrucao(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getGrauinstrucao(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getPais(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getPais(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getEstado(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getEstado(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getMunicipio(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            
            $cdpais = isset($params['CDPAIS']) ? $params['CDPAIS'] : null;
            $cdestado = isset($params['SGESTADO']) ? $params['SGESTADO'] : null;

            $data = $this->minhaHistoriaService->getMunicipio(
                $nrorg, $cdpais, $cdestado
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getNacionalidade(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getNacionalidade(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getClasseEstrang(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getClasseEstrang(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getConselhoRegional(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getConselhoRegional(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getCategoriaMilitar(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getCategoriaMilitar(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getBanco(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getBanco(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getAgencia(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];
            $cdbanco = isset($params['CDBANCO']) ? $params['CDBANCO'] : null;

            $data = $this->minhaHistoriaService->getAgencia(
                $nrorg, $cdbanco
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getTpContaCorrente(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getTpContaCorrente(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getLogradouro(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getLogradouro(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getTpEndereco(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getTpEndereco(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getOperadores(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();

            $nrorg = $params['NRORG'];

            $data = $this->minhaHistoriaService->getOperadores(
                $nrorg
            );
            $response->addDataSet(new DataSet('data', $data));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
}